summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRiddle Hsu <riddlehsu@google.com>2021-08-11 03:51:48 +0000
committerAndroid (Google) Code Review <android-gerrit@google.com>2021-08-11 03:51:48 +0000
commit58c7e9499c1b05c311eb03308a084137c44012f3 (patch)
tree015c28295b5466bda0ea142addc905b976ebc47d
parent88612b95d4c8e9a6cd19c3e2a3fb5a46712966a8 (diff)
parentfaf59661282d73449593e5f240717b7361f8bed6 (diff)
downloadbase-58c7e9499c1b05c311eb03308a084137c44012f3.tar.gz
Merge "Allow to use fixed rotation if recents is animating" into sc-dev
-rw-r--r--services/core/java/com/android/server/wm/DisplayContent.java6
1 files changed, 4 insertions, 2 deletions
diff --git a/services/core/java/com/android/server/wm/DisplayContent.java b/services/core/java/com/android/server/wm/DisplayContent.java
index 1b799dfbdaab..dbc1116ad389 100644
--- a/services/core/java/com/android/server/wm/DisplayContent.java
+++ b/services/core/java/com/android/server/wm/DisplayContent.java
@@ -1593,8 +1593,10 @@ class DisplayContent extends RootDisplayArea implements WindowManagerPolicy.Disp
// If the transition has not started yet, the activity must be the top.
return false;
}
- if (mLastWallpaperVisible && r.windowsCanBeWallpaperTarget()) {
- // Use normal rotation animation for orientation change of visible wallpaper.
+ if (mLastWallpaperVisible && r.windowsCanBeWallpaperTarget()
+ && mFixedRotationTransitionListener.mAnimatingRecents == null) {
+ // Use normal rotation animation for orientation change of visible wallpaper if recents
+ // animation is not running (it may be swiping to home).
return false;
}
final int rotation = rotationForActivityInDifferentOrientation(r);